pub struct CalendarChart {Show 63 fields
pub width: f32,
pub height: f32,
pub x: f32,
pub y: f32,
pub margin: Box,
pub font_family: String,
pub background_color: Color,
pub is_light: bool,
pub title_text: String,
pub title_font_size: f32,
pub title_font_color: Color,
pub title_font_weight: Option<String>,
pub title_margin: Option<Box>,
pub title_align: Align,
pub title_height: f32,
pub sub_title_text: String,
pub sub_title_font_size: f32,
pub sub_title_font_color: Color,
pub sub_title_font_weight: Option<String>,
pub sub_title_margin: Option<Box>,
pub sub_title_align: Align,
pub sub_title_height: f32,
pub legend_font_size: f32,
pub legend_font_color: Color,
pub legend_font_weight: Option<String>,
pub legend_align: Align,
pub legend_margin: Option<Box>,
pub legend_category: LegendCategory,
pub legend_show: Option<bool>,
pub x_axis_data: Vec<String>,
pub x_axis_height: f32,
pub x_axis_stroke_color: Color,
pub x_axis_font_size: f32,
pub x_axis_font_color: Color,
pub x_axis_font_weight: Option<String>,
pub x_axis_name_gap: f32,
pub x_axis_name_rotate: f32,
pub x_axis_margin: Option<Box>,
pub x_axis_hidden: bool,
pub x_boundary_gap: Option<bool>,
pub y_axis_hidden: bool,
pub series_stroke_width: f32,
pub series_label_font_color: Color,
pub series_label_font_size: f32,
pub series_label_font_weight: Option<String>,
pub series_label_formatter: String,
pub series_colors: Vec<Color>,
pub series_symbol: Option<Symbol>,
pub series_smooth: bool,
pub series_fill: bool,
pub data: Vec<(String, f32)>,
pub start_date: String,
pub end_date: String,
pub min: f32,
pub max: f32,
pub min_color: Color,
pub max_color: Color,
pub empty_color: Color,
pub cell_size: f32,
pub cell_gap: f32,
pub month_label_height: f32,
pub week_label_width: f32,
pub show_dow_labels: Vec<usize>,
/* private fields */
}Fields
width: f32height: f32x: f32y: f32margin: Boxfont_family: Stringbackground_color: Coloris_light: booltitle_text: Stringtitle_font_size: f32title_font_color: Colortitle_font_weight: Option<String>title_margin: Option<Box>title_align: Aligntitle_height: f32sub_title_text: Stringsub_title_font_size: f32sub_title_font_color: Colorsub_title_font_weight: Option<String>sub_title_margin: Option<Box>sub_title_align: Alignsub_title_height: f32legend_font_size: f32legend_font_color: Colorlegend_font_weight: Option<String>legend_align: Alignlegend_margin: Option<Box>legend_category: LegendCategorylegend_show: Option<bool>x_axis_data: Vec<String>x_axis_height: f32x_axis_stroke_color: Colorx_axis_font_size: f32x_axis_font_color: Colorx_axis_font_weight: Option<String>x_axis_name_gap: f32x_axis_name_rotate: f32x_axis_margin: Option<Box>x_boundary_gap: Option<bool>series_stroke_width: f32series_label_font_color: Colorseries_label_font_size: f32series_label_font_weight: Option<String>series_label_formatter: Stringseries_colors: Vec<Color>series_symbol: Option<Symbol>series_smooth: boolseries_fill: booldata: Vec<(String, f32)>Data points: each entry is ("YYYY-MM-DD", value).
start_date: StringFirst day shown, inclusive. Format: "YYYY-MM-DD".
end_date: StringLast day shown, inclusive. Format: "YYYY-MM-DD".
min: f32Value that maps to min_color. Auto-computed from data when 0.
max: f32Value that maps to max_color. Auto-computed from data when 0.
min_color: ColorColor for cells with the minimum value (default: light gray).
max_color: ColorColor for cells with the maximum value (default: green).
empty_color: ColorColor for cells that have no data entry.
cell_size: f32Side length of each day square in pixels (default: 13).
cell_gap: f32Gap between adjacent squares in pixels (default: 3).
month_label_height: f32Height of the month-label row at the top of the grid (default: 20).
week_label_width: f32Width of the day-of-week label column at the left of the grid (default: 30).
show_dow_labels: Vec<usize>Rows of the day-of-week labels to display.
Each entry is a day-of-week index (0 = Sun … 6 = Sat).
Defaults to [1, 3, 5] (Mon, Wed, Fri), matching the GitHub style.
Implementations
Sourceimpl CalendarChart
impl CalendarChart
Sourcepub fn new(data: Vec<(String, f32)>, year: i32) -> CalendarChart
pub fn new(data: Vec<(String, f32)>, year: i32) -> CalendarChart
Creates a calendar chart for year (Jan 1 – Dec 31) with default theme.
Sourcepub fn new_with_theme(
data: Vec<(String, f32)>,
year: i32,
theme: &str,
) -> CalendarChart
pub fn new_with_theme( data: Vec<(String, f32)>, year: i32, theme: &str, ) -> CalendarChart
Creates a calendar chart for year with a custom theme.
Sourcepub fn from_json(json: &str) -> Result<CalendarChart>
pub fn from_json(json: &str) -> Result<CalendarChart>
Creates a calendar chart from a JSON string.