pub struct WaterfallData {
pub value: f32,
pub is_total: bool,
}Expand description
A single bar in the waterfall chart.
Fields
value: f32The numeric value for this bar (positive = increase, negative = decrease).
For is_total = true bars this is the cumulative value to display (usually
computed automatically, but can be set explicitly if you want to override it).
is_total: boolWhen true this bar is rendered as a “total” bar that starts at 0 and
spans to the current running sum. Colors it with total_color.